# A note for ASP-DAC 2021 reviewers

This repository was prepared from the original. The authors of contributed to many of these design. Therefore, some, but not all, license and author information was removed for review blinding. Some example license and author information that was not removed is located in the individual directories for each design (for example [bm1/bm1.license.txt](bm1/bm1.license.txt))

The unblinded repository contains full license and author citations for all designs.

# PCBBenchmarks

KiCad PCB benchmarks for automated layout. 
